==> nextcloud-13.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ko.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "미리 보기 불러오는 중…",
    "Saved" : "저장됨",
    "Admin" : "관리자",
    "a safe home for all your data" : "내 모든 데이터 안전 저장소",
    "The given name is too long" : "입력한 이름이 너무 김",
    "The given web address is too long" : "입력한 웹 주소가 너무 김",
    "The given slogan is too long" : "입력한 슬로건이 너무 김",
    "The given color is invalid" : "입력한 색상이 잘못됨",
    "There is no error, the file uploaded with success" : "오류 없음, 파일 업로드 성공",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "The uploaded file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "Failed to write file to disk." : "디스크에 파일을 기록할 수 없습니다.",
    "A PHP extension stopped the file upload." : "PHP 확장 기능에서 파일 업로드를 차단했습니다.",
    "No file uploaded" : "업로드한 파일 없음",
    "Unsupported image type" : "지원하지 않는 사진 형식",
    "You are already using a custom theme" : "이미 사용자 정의 테마 사용 중",
    "Theming" : "테마",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
    "Name" : "이름",
    "Reset to default" : "기본값으로 초기화",
    "Web address" : "웹 주소",
    "Web address https://…" : "웹 주소 https://…",
    "Slogan" : "슬로건",
    "Color" : "색",
    "Logo" : "로고",
    "Upload new logo" : "새 로고 업로드",
    "Login image" : "로그인 그림",
    "Upload new login background" : "새 로그인 배경 업로드",
    "Remove background image" : "배경 그림 삭제",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "업로드한 로고와 색으로부터 자동으로 파비콘을 생성하려면 PHP Imagemagick 확장 기능 및 SVG 형식 그림 지원을 설치하십시오.",
    "reset to default" : "기본값으로 초기화"
},
"nplurals=1; plural=0;");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/ko.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "미리 보기 불러오는 중…",
    "Saved" : "저장됨",
    "Admin" : "관리자",
    "a safe home for all your data" : "내 모든 데이터 안전 저장소",
    "The given name is too long" : "입력한 이름이 너무 김",
    "The given web address is too long" : "입력한 웹 주소가 너무 김",
    "The given slogan is too long" : "입력한 슬로건이 너무 김",
    "The given color is invalid" : "입력한 색상이 잘못됨",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "업로드한 파일의 크기가 php.ini의 upload_max_filesize를 초과함",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "업로드한 파일의 크기가 HTML 폼에 지정한 MAX_FILE_SIZE를 초과함",
    "No file was uploaded" : "업로드한 파일 없음",
    "Missing a temporary folder" : "임시 폴더 없음",
    "No file uploaded" : "업로드한 파일 없음",
    "Unsupported image type" : "지원하지 않는 사진 형식",
    "Theming" : "테마",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "테마를 사용하여 내 인스턴스와 지원하는 클라이언트의 모습을 변경할 수 있습니다. 테마는 모든 사용자에게 적용됩니다.",
    "Name" : "이름",
    "Reset to default" : "기본값으로 초기화",
    "Web address" : "웹 주소",
    "Web address https://…" : "웹 주소 https://…",
    "Slogan" : "슬로건",
    "Color" : "색",
    "Logo" : "로고",
    "Upload new logo" : "새 로고 업로드",
    "Login image" : "로그인 그림",
    "Upload new login background" : "새 로그인 배경 업로드",
    "Remove background image" : "배경 그림 삭제",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "업로드한 로고와 색으로부터 자동으로 파비콘을 생성하려면 PHP Imagemagick 확장 기능 및 SVG 형식 그림 지원을 설치하십시오.",
    "You are already using a custom theme" : "이미 사용자 정의 테마 사용 중",
    "reset to default" : "기본값으로 초기화",
    "There is no error, the file uploaded with success" : "오류 없음, 파일 업로드 성공",
    "The uploaded file was only partially uploaded" : "파일이 일부분만 업로드됨",
    "Failed to write file to disk." : "디스크에 파일을 기록할 수 없습니다.",
    "A PHP extension stopped the file upload." : "PHP 확장 기능에서 파일 업로드를 차단했습니다."
},
"nplurals=1; plural=0;");
